==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/english/original_sections/admin/configuration/configuration_links.lang.inc.php <==
<?php
/*
 * configuration_links.lang.inc.php 2020-08-04
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = [
    'LINK_SHOP_KEY'                   => 'Shop-Key',
    'LINK_LOGO_MANAGER'               => 'Logo-Manager',
    'LINK_IMAGEPROCESSING'            => 'Image-Processing',
    'LINK_MAINTENANCE_MODE'           => 'Shop online / offline',
    'LINK_EXPORT_CONSENT_PROTOCOL'    => 'Creates a CSV file with all customers which have agreed to the legal texts of the shop',
    'LINK_CAMPAIGNS'                  => 'Campaigns',
    'LINK_SHIPPING_STATUS'            => 'Shipping status',
    'LINK_PARCEL_SERVICES'            => 'Parcel services',
    'LINK_INVOICE_PACKING_SLIP'       => 'Invoice / Packing Slip',
    'LINK_ORDERS_AND_CUSTOMERS_RANGE' => 'Orders and customers IDs',
    'LINK_SEO_META'                   => 'Meta Data',
    'LINK_SEO_ROBOTS'                 => 'Robots.txt file',
    'LINK_SEO_SITEMAP'                => 'Sitemap Generator',
    'LINK_SEO_STATIC_PAGES'           => 'Static Pages',
    'LINK_TRACKING_CODES'             => 'Traking-Codes',
    'LINK_TAX_CLASSES'                => 'Tax Classes',
    'LINK_TAX_RATES'                  => 'Tax Rates',
    'LINK_TAX_GEO_ZONES'              => 'Tax Zones',
    'LINK_COUNTRIES_COUNTRIES'        => 'Countries',
    'LINK_COUNTRIES_CURRENCIES'       => 'Currencies',
    'LINK_COUNTRIES_ZONES'            => 'Zones',
    'LINK_COUNTRIES_LANGUAGES'        => 'Languages',
    'LINK_COOKIE_CONSENT' => 'Cookie Consent'
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/english/original_sections/admin/configuration/configuration_links.lang.inc.php <==
<?php
/*
 * configuration_links.lang.inc.php 2020-08-04
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = [
    'LINK_SHOP_KEY'                   => 'Shop-Key',
    'LINK_LOGO_MANAGER'               => 'Logo-Manager',
    'LINK_IMAGEPROCESSING'            => 'Image-Processing',
    'LINK_MAINTENANCE_MODE'           => 'Shop Online / Offline',
    'LINK_EXPORT_CONSENT_PROTOCOL'    => 'Creates a CSV file with all customers which have agreed to the legal texts of the shop',
    'LINK_CAMPAIGNS'                  => 'Campaigns',
    'LINK_SHIPPING_STATUS'            => 'Shipping Status',
    'LINK_PARCEL_SERVICES'            => 'Parcel Services',
    'LINK_INVOICE_PACKING_SLIP'       => 'Invoice / Packing Slip',
    'LINK_ORDERS_AND_CUSTOMERS_RANGE' => 'Orders and Customers IDs',
    'LINK_SEO_META'                   => 'Meta Data',
    'LINK_SEO_ROBOTS'                 => 'Robots.txt File',
    'LINK_SEO_SITEMAP'                => 'Sitemap Generator',
    'LINK_SEO_STATIC_PAGES'           => 'Static Pages',
    'LINK_TRACKING_CODES'             => 'Tracking Codes',
    'LINK_TAX_CLASSES'                => 'Tax Classes',
    'LINK_TAX_RATES'                  => 'Tax Rates',
    'LINK_TAX_GEO_ZONES'              => 'Tax Zones',
    'LINK_COUNTRIES_COUNTRIES'        => 'Countries',
    'LINK_COUNTRIES_CURRENCIES'       => 'Currencies',
    'LINK_COUNTRIES_ZONES'            => 'Zones',
    'LINK_COUNTRIES_LANGUAGES'        => 'Languages',
    'LINK_COOKIE_CONSENT' => 'Cookie Consent'
];
